Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(523)

Unified Diff: services/ui/display/screen_manager_stub_internal.h

Issue 2685003002: Rename ScreeManagerOzone to ScreenManagerOzoneInternal (Closed)
Patch Set: patch for landing Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/display/screen_manager_stub.cc ('k') | services/ui/display/screen_manager_stub_internal.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/display/screen_manager_stub_internal.h
diff --git a/services/ui/display/screen_manager_stub.h b/services/ui/display/screen_manager_stub_internal.h
similarity index 63%
rename from services/ui/display/screen_manager_stub.h
rename to services/ui/display/screen_manager_stub_internal.h
index b780bb4d9dc7dc65bbba8eb44bfcb46b4b40dc2e..bda52eb8e4ad596393ec82c3f9ca9fb4eabf279c 100644
--- a/services/ui/display/screen_manager_stub.h
+++ b/services/ui/display/screen_manager_stub_internal.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_H_
-#define SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_H_
+#ifndef SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_INTERNAL_H_
+#define SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_INTERNAL_H_
#include <stdint.h>
@@ -13,12 +13,13 @@
namespace display {
// ScreenManagerStub provides the necessary functionality to configure a fixed
// 1024x768 display for non-ozone platforms.
-class ScreenManagerStub : public ScreenManager {
+class ScreenManagerStubInternal : public ScreenManager {
public:
- ScreenManagerStub();
- ~ScreenManagerStub() override;
+ ScreenManagerStubInternal();
+ ~ScreenManagerStubInternal() override;
private:
// Fake creation of a single 1024x768 display.
@@ -36,11 +37,11 @@ class ScreenManagerStub : public ScreenManager {
ScreenManagerDelegate* delegate_ = nullptr;
- base::WeakPtrFactory<ScreenManagerStub> weak_ptr_factory_;
+ base::WeakPtrFactory<ScreenManagerStubInternal> weak_ptr_factory_;
- DISALLOW_COPY_AND_ASSIGN(ScreenManagerStub);
+ DISALLOW_COPY_AND_ASSIGN(ScreenManagerStubInternal);
};
} // namespace display
-#endif // SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_H_
+#endif // SERVICES_UI_DISPLAY_SCREEN_MANAGER_STUB_INTERNAL_H_
« no previous file with comments | « services/ui/display/screen_manager_stub.cc ('k') | services/ui/display/screen_manager_stub_internal.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -13,12 +13,13 @@
namespace display {
-// ScreenManagerStub provides the necessary functionality to configure a fixed
+// ScreenManagerStubInternal provides the necessary functionality to configure a
+// fixed
// 1024x768 display for non-ozone platforms.
This is Rietveld 408576698